@@ -1,7 +1,8 @@
 """Manage videos from the Canal+ website."""
 
 class Show(object):
-
+    """Describe a single Canal+ show."""
+    # pylint: disable-msg=R0903
     def __init__(self, pid, nickname, fullname):
         self.pid = pid
         self.nickname = nickname
