@@ -5,6 +5,7 @@
 import os
 import shutil
 
+import canalweb
 from canalweb import vod
 
 ROOT = os.path.dirname(__file__)
@@ -28,13 +29,14 @@ class TestDownloader(object):
         """Check exraction of video IDs."""
         fd = open(os.path.join(ROOT, 'testdata', 'pid1830-c-zapping.html'))
 
-        assert [url for url in self.dl.extract_content_ids(fd)] == [
+        assert [url for url in self.dl._extract_content_ids(fd)] == [
             195190, 195164, 194541, 194196, 193817, 193423, 193128, 192859]
 
     def test_config(self):
         """Check parsing of the XML file."""
         data = open(os.path.join(ROOT, 'testdata', 'video-config.xml')).read()
-        video = self.dl._video_url(data, 'guignoles', 1234)
+        show = canalweb.SHOW_BY_NICK['guignoles']
+        video = self.dl._video_url(data, show, 1234)
 
         assert video.url == (
             'http://vod-flash.canalplus.fr/WWWPLUS/PROGRESSIF'
